@@ -1,11 +1,11 @@
 /*
- * GNU GTick  -  A GTK+ Metronome
+ * gnu gtick  -  a gtk+ metronome
  *
- * gtick.c: Main app code
+ * gtick.c: main app code
  * 
  *
- * Copyright (c) 1999 Alex Roberts
- * Copyright (c) 2003, 2004 Roland Stigge <stigge@antcom.de>
+ * copyright (c) 1999 alex roberts
+ * Copyright (c) 2003, 2004, 2005, 2006 Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,7 +19,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
@@ -109,7 +109,9 @@ Options:\n\
   }
 #endif
 
-  g_thread_init(NULL);
+  if (!g_thread_supported()) {
+    g_thread_init(NULL);
+  }
 
   /* Initialise UI */
   metro = metro_new();
