@@ -5,7 +5,7 @@
  * 
  *
  * Copyright (c) 1999, Alex Roberts
- * Copyright (c) 2003, Roland Stigge <stigge@antcom.de>
+ * Copyright (c) 2003, 2004, 2005, 2006  Roland Stigge <stigge@antcom.de>
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,17 +19,17 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
 
-#ifndef ABOUT_H
-#define ABOUT_H
+#ifndef HELP_H
+#define HELP_H
 
 #include "metro.h"
 
-void about_box(metro_t* metro);
 void license_box(void);
-void help_shortcuts(void);
+void about_box(GtkAction *action, metro_t *metro);
+void help_shortcuts(GtkAction *action, metro_t *metro);
 
-#endif /* ABOUT_H */
+#endif /* HELP_H */
