@@ -38,6 +38,7 @@
 #include <time.h>
 #include <pwd.h>
 #include <sys/stat.h>
+#include <sys/wait.h>
 #include <errno.h>
 
 /* GTK+ headers */
@@ -135,6 +136,8 @@ void execute(char *command) {
       fprintf(stderr, "Exec error.\n");
       exit(1);
     }
+  } else { /* we are the parent */
+    waitpid(result, NULL, 0);
   }
 }
 
